/*
mandofountain.sqf v1.3 
by Mandoble
Generates water from fountains
Arguments:
 fountain object
 [x,y,z] relative to fountain position to adjust pipe placement
 Initial angle from where the water will spread relative to water fountain object
 Arc from initial angle from where the water may be spread left and right
 Initial horizontal speed of water drops in m/s
 Initial vertical speed of water drops in m/s
 Number of simultaneous drops
 Number identitying this fountain
 sizes array or just [] if you want to use the default one
 colors array or just [] if you want to use the default one
 Life-time of the particles (> 1 and <= 4)

 The ID number is used to create four internal variables for the fountain (## is the id):
   mando_fountain_arcini_##
   mando_fountain_deg_##
   mando_fountain_spd_##
   mando_fountain_spv_##
 
 You may modify the values of these variables from outside the script to change dinamically the water effect.
 Use setVariable command to modify these internal vars.  

 Example:
 [fountain1,[0,0,3.2],0,360,0.5,16,1,[],[],3]execVM"mandofountain.sqf";
*/

private["_fountain", "_delta", "_arcini", "_deg", "_spd", "_spdv", "_numdrops", "_color", "_size", "_dur","_rot", "_pos", "_mass", "_vol", "_i", "_ang", "_vel", "_fount_id"];

_fountain   = _this select 0;
_delta    = _this select 1;
_arcini   = _this select 2;
_deg      = _this select 3;
_spd      = _this select 4;
_spdv     = _this select 5;
_numdrops = _this select 6;
_id       = _this select 7;
_size     = _this select 8;
_color    = _this select 9;
_dur      = _this select 10;

stop_fountain = false;
if (count _color == 0) then
{
   _color = [[1,1,1,0.3],[0.5,1,1,0.2],[1,1,1,0.2],[0.5,1,1,0.2],[1,1,1,0.2],[0.5,1,1,0.2],[0.5,1,1,0.8],[1,1,1,1]];
};

if (count _size == 0) then
{
   _size = [0.05,0.05,0.2,0.2,0.1,0.3];
};

_fountain setVariable [format["mando_fountain_arcini_%1", _id], _arcini];
_fountain setVariable [format["mando_fountain_deg_%1", _id], _deg];
_fountain setVariable [format["mando_fountain_spd_%1", _id], _spd];
_fountain setVariable [format["mando_fountain_spdv_%1", _id], _spdv];

if (_dur > 4) then
{
   _dur = 3;
};

_rot  = 1;

_mass = 2.0;
_vol  = 1;

while {!alive player} do
{
   Sleep 1;
};


while {(damage _fountain < 0.5) && !stop_fountain} do
{
   while {((vehicle player) distance _fountain) > 1000} do
   {
      Sleep 1;
   };

   _arcini = _fountain getVariable (format["mando_fountain_arcini_%1", _id]);
   _deg = _fountain getVariable (format["mando_fountain_deg_%1", _id]);
   _spd = _fountain getVariable (format["mando_fountain_spd_%1", _id]);
   _spdv = _fountain getVariable (format["mando_fountain_spdv_%1", _id]);

   _pos = _delta;

   for [{_i=0},{_i<_numdrops/2},{_i=_i+1}] do
   {
      _ang = (_arcini - _deg/2 + random(_deg));
      _vel = [sin(_ang)*_spd, cos(_ang)*_spd, _spdv];
      drop[ ["\Ca\Data\ParticleEffects\CloudletWater\CloudletWater.p3d", 4, 1, 1],"","Billboard",100,_dur,_pos,_vel,_rot,_mass,_vol,0,_size,_color,[1,0,1,0,1],1,0.1,"","",_fountain];
      _ang = (_arcini - _deg/2 + random(_deg));
      _vel = [sin(_ang)*_spd, cos(_ang)*_spd, _spdv];
      drop[["\Ca\Data\ParticleEffects\CloudletWater\CloudletWater.p3d", 4, 0, 1],"","Billboard",100,_dur,_pos,_vel,_rot,_mass,_vol,0,_size,_color,[1,0,1,0,1],1,0.1,"","",_fountain];
      Sleep 0;
   };
   Sleep 0.01;
};